import {contentType, Ajax} from './ajax';
import axios from 'axios';
import qs from '../res/qs';
import string_tool from './string_tool';


class AjaxPro {
  constructor({
                url,
                data = {},
                sendType = 'get',
                resultType = 'json',
                loading = true
              }) {
    this.loading = false;
    this.url = url;
    this.data = data;
    this.sendType = sendType;
    this.resultType = resultType;
    this.useLoading = loading;

  }

  onEnd() {
    this.loading = false;
    if (this.useLoading) {
      Ajax.onEnd();
    }
  }

  submit(data = {}, url) {
    //阻止重复提交
    if (this.loading) {
      return;
    }
    this.loading = true;
    const newPara = Object.assign({}, this.data, data);

    const header = {
      'X-Requested-With': 'XMLHttpRequest',
      'Content-Type': contentType[this.sendType],
      token: Ajax.header.token
    };
    let responseType;
    if (this.resultType === 'blob') {
      responseType = 'blob';
    }

    if (this.useLoading) {
      Ajax.onStart();
    }
    const sendData = {
      method: 'get',
      url: url || this.url,
      timeout: 30000,
      headers: header,
      responseType
    };
    switch (this.sendType) {
      case 'get':
        sendData.params = newPara;
        break;
      case 'post':
        sendData.method = 'post';
        sendData.data = qs.stringify(newPara);
        break;
      case 'postJson':
        sendData.method = 'post';
        sendData.data = newPara;
        break;
    }
    return axios(sendData).catch(err => {
      this.onEnd();
      console.log('接口调用出错', {
        '接口地址': this.url,
        '提交参数': newPara,
        '提交方式': this.sendType,
        '错误信息': err
      });
      return Promise.reject(err);
    }).then(result => {
      this.result = result;
      this.onEnd();
      switch (this.resultType) {
        case 'json':
          if (typeof result.data === 'object') {
            return result.data;
          } else {
            return Promise.reject('服务端未返回有效json数据');
          }
        case 'text':
          return result.data;
        case 'blob':
          return result.data;
      }
    });
  }
}

export default AjaxPro;
