import Validate from "./validate";
import DateTool from "./date_tool";

export default class Base_model {

  constructor() {
    this.$idField = 'id';             // 标识列
    this.$dataList = [];             // 接口返回的数组

    this.$defaults = {};            // 初始属性 该项必须在子类中重新定义
    this.$listMode = 'get';     // 调用set接口时的模式，可选值post、postJson、get，需要跟后台对应起来
    this.$setMode = 'postJson';     // 调用set接口时的模式，可选值post、postJson、get，需要跟后台对应起来
    this.$delMode = 'postJson';     // 调用delete接口时的模式，可选值post、postJson、get，需要跟后台对应起来

    this.$limit = 20;
    this.id = '';

    this.$total = 0;
    this.$totalPage = 0;
    this.$end = false;
    this.$nowPage = 1;


    //以下两者分离，是为了避免表单数值改变后，用户没有点搜索的情况
    this.$searchForm = {};        //搜索表单绑定的数据
    this.$searchPara = {};        //实际传递到后台的数据

    this.$rule = {};
    this.$validate = null;
    this.$map = [];


  }

  $setDefPara(key, value) {
    this.$searchPara[key] = this.$searchForm[key] = value;
  }

  $addMap(serverName, localName) {
    this.$map.push({
      serverName,
      localName
    });
  }

  /**
   * 初始化类 将$props中所有属性名称存入$keys，方便调用
   */
  $init() {
    this.$keys = Object.keys(this.$defaults);
    this.$new();
    this.$validate = new Validate(this, this.$rule);
  }

  $check() {
    return this.$validate.checkPro(this);
  }

  /**
   * 将所有属性重置为默认值
   */
  $new() {
    Object.assign(this, this.$defaults);
  }

  /**
   * 应用查询参数
   */
  $search() {
    this.$nowPage = 1;
    this.$end = false;
    Object.assign(this.$searchPara, this.$searchForm);
    const keys = Object.keys(this.$searchPara);
    //自动去除空值
    keys.forEach((key) => {
      if (this.$searchPara[key] === '') {
        this.$searchPara[key] = undefined;
      }
    });
    this.$beforeSearch(this.$searchPara, this.$searchForm);
  }

  /**
   * 重置limit
   * @param limit
   */
  $setLimit(limit) {
    this.$nowPage = 1;
    this.$end = false;
    this.$limit = limit;
  }

  /**
   * $getPageDataPro（分页list）加载完成后触发
   * 用于对后端输出的数据作额外处理
   * @param data
   */
  $afterGetList(data) {
    return data;
  }

  /**
   * $getData调用成功后触发
   * 用于对后端输出的数据作额外处理
   * @param data
   */
  $afterGet() {
  }

  /**
   *
   /**
   * 事件 当用户点击搜索（应用搜索条件）时触发
   * 事件内可对$searchPara中的数据进行转换
   * @param result = this.$searchPara
   * @param source = this.$searchForm
   */
  $beforeSearch(result, source) {

  }

  $find(id) {
    return this.$dataList.find(function (item) {
      return item.id === id;
    })
  }

  /**
   * 数据转换
   * 该方法在$getData获取数据后调用
   * 该方法仅供子类内部调用
   */
  $convertServerData(data) {
    if (this.$map.length === 0) {
      return;
    }
    this.$map.forEach((item) => {
      data[item.localName] = data[item.serverName];
    });
  }

  /**
   * 数据转换
   * 该方法在$setData提交数据前调用
   * 该方法仅供子类内部调用
   */
  $convertLocalData() {
    const data = {};
    if (this.$map.length === 0) {
      return data;
    }
    this.$map.forEach((item) => {
      data[item.serverName] = data[item.localName];
    });

    return data;
  }

  /**
   * 数据转换
   * 该方法仅供子类内部调用
   */
  $arrayConvert(data) {
    const $map = this.$map;
    if ($map.length === 0) {
      return;
    }
    data.forEach(function (row) {
      $map.forEach(function (config) {
        row[config.localName] = row[config.serverName];
      });
    })
  }

  /**
   * 设置时间段查询参数
   * @param date - 日期时间段选择器所绑定的model
   * @param opt -
   */
  $setSearchDatePara(date, opt) {
    opt = Object.assign({
      startField: 'startDate',
      endField: 'endDate',
      addDay: true,
      fmt: 'yyyy-MM-dd hh:mm:ss'
    }, opt || {});
    const paras = this.$searchPara;
    if (date && date.length === 2) {
      paras[opt.startField] = DateTool.parse(date[0]).format(opt.fmt);
      if (opt.addDay) {
        paras[opt.endField] = DateTool.parse(date[1]).addDays(1).format(opt.fmt);
      } else {
        paras[opt.endField] = DateTool.parse(date[1]).format(opt.fmt);
      }
    } else {
      paras[opt.startField] = undefined;
      paras[opt.endField] = undefined;
    }

  }

  //删除方法的别名
  $remove(id, key) {
    return this.$delData(id, key);
  }

  //保存的别名
  $save(otherData) {
    return this.$setData(otherData)
  }

  //getPage的别名
  $loadList() {
    return this.$getPageData(this.$nowPage);
  }
}
