import tsToDate from "./date_tool/ts_to_date";

class Html {

  constructor(html: string) {
    this._html = html;
  }

  /**
   * 替换标记
   * @param key
   * @param value
   */
  replace(key: string, value: string) {
    this._html = this._html.replaceSign(key, value);
  }

  /**
   * 输出结果
   * @returns {string}
   */
  toString() {
    return this._html;
  }
}

/**
 * 判断对象类型
 * @param {Object} object
 * @returns {string} - Null、Undefined、String、Number、Boolean、Function、Date、Array、Object
 */
function getType(object) {
  return Object.prototype.toString.call(object).match(/^\[object\s(.*)\]$/)[1];
}

/**
 * 输出html
 * @param data - array 数据源
 * @param template - string，不能为空
 * @param filter function|object：function：设置filter，object：同时设置keys和filter
 * @returns {*}
 */
function arrToHtml(data: Array<any>, template: string, filter?: any) {
  if (!Array.isArray(data)) {
    console.log('MyMath.arrToHtml', 'data必须为array');
    return '';
  }
  if (data.length === 0) {
    return '';
  }
  if (typeof template !== 'string' || template.length === 0) {
    console.log('MyMath.arrToHtml', 'template不能为空');
    return;
  }
  const keys = Object.keys(data[0]);
  const useFilter = (typeof filter === 'function');

  let _filter = function () {
  };

  if (useFilter) {
    _filter = filter;
  }
  const result = [];
  data.forEach((item, index) => {
    const html = new Html(template);
    if (useFilter) {
      _filter.call(html, item, index + 1);
    }
    keys.forEach((key) => {
      if (item[key] === null || item[key] === undefined) {
        item[key] = '';
      }
      html.replace(key, item[key]);
    });
    result.push(html.toString());
  });
  return result.join('');

}

/**
 * 复制部分属性
 * @param target - 目标对象
 * @param source - 源对象
 * @param keys - 需要复制的字段
 */
function assign(target: Object, source: Object, keys: Array<string>) {
  keys.forEach(key => {
    target[key] = source[key];
  });
  return target;
}

/**
 * 构建查询参数
 */
function buildGetPara(paras: Object) {
  const keys = Object.keys(paras), result = [];
  keys.forEach(function (item) {
      if (paras[item] !== undefined && paras[item] !== '') {
        result.push(`&${item}=${encodeURI(paras[item])}`);
      }
    }
  );
  let str = result.join('');
  if (str) {
    str = str.substr(1);
  }
  return str;
}

/**
 * 将对象的所有属性设置为空值
 * 主要用于重置表单数据
 * @param obj
 */
function clearFormData(obj: Object) {
  Object.keys(obj).forEach(function (key) {
    obj[key] = '';
  });
}

/**
 * 将对象中以date或time结尾的属性，从时间戳转换为Date
 * 该方法暂无使用场景
 * @param obj
 * @param fmt
 */
function convertTime(obj: Object, fmt) {
  const useFormat = typeof fmt === 'string';
  Object.keys(obj).forEach(function (key) {
    if (/(date|time)$/i.test(key)) {
      if (useFormat) {
        obj[key] = tsToDate(obj[key]).format(fmt);
      } else {
        obj[key] = tsToDate(obj[key]);
      }
    }
  })
}

/**
 * 获取地址栏查询参数
 */
function getPara() {
  let queryStr = self.location.href.split("?"),
    GETs, result = {}, item;
  if (queryStr[1]) {
    //过滤掉#及其后面的部分
    GETs = queryStr[1].toString().split('#')[0].split("&");
    for (let i = 0; i < GETs.length; i++) {
      item = GETs[i].split("=");
      result[item[0].toLowerCase()] = item[1];
    }
  }
  return result;
}

/**
 * 判断对方是否使用IOS进行访问
 * @returns {boolean}
 */
function isIos() {
  const u = navigator.userAgent;
  return !!u.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/);
}

export {
  getType,
  arrToHtml,
  assign,
  buildGetPara,
  clearFormData,
  convertTime,
  getPara,
  isIos,
}

export default {
  getType,
  arrToHtml,
  assign,
  buildGetPara,
  clearFormData,
  convertTime,
  getPara,
  isIos,
}
