/* @flow weak */

const storage = localStorage;

class Cache {

    /**
     * 缓存string
     * @param {string} key
     * @param {string} value
     */
    static set(key: string, value: string) {
        storage.setItem(key, value);
    }

    /**
     * 将json对象转为字符后进行缓存
     * @param {string} key
     * @param {object} value
     */
    static setJson(key: string, value: any) {
        storage.setItem(key, JSON.stringify(value));
    }

    /**
     * 读取string
     * @param {string} key
     * @returns {string}
     */
    static get(key: string) {
        return storage.getItem(key) || '';
    }


    /**
     * 读取string
     * @param {string} key
     * @returns {string}
     */
    static has(key: string) {
        return storage.getItem(key) !== null;
    }
    /**
     * 读取缓存
     * @param {string} key
     * @param {string} 默认值
     * @returns {object}
     */
    static getJson(key: string, defaultValue = {}) {
        const result = storage.getItem(key);
        return result ? JSON.parse(result) : defaultValue;
    }


    /**
     * 清除缓存
     * @param {string} key
     */
    static remove(key: string) {
        storage.removeItem(key);
    }
}

export {Cache};
export default Cache;
