/* @flow weak */
import Ajax from "./ajax";
import {assign} from "./basic";
import baseModel from "./base_model";
import rollingData from "../mobile/rolling_data";


/**
 * 数据实体基类 action模式
 */
class DataModel extends baseModel {

  constructor() {
    super();

    this.$api = '';                  // 接口地址
    this.$listAction = '';           // 分页读取数据 Action
    this.$listAllAction = '';           //读取所有数据 Action
    this.$getAction = '';             // get单条数据 Action
    this.$setAction = '';             // 保存（添加、修改）数据 Action
    this.$delAction = '';           // 删除数据 Action
    this.$setMode = 'post';     // 调用set接口时的模式，可选值post、postJson、get，需要跟后台对应起来
    this.$delMode = 'post';     // 调用delete接口时的模式，可选值post、postJson、get，需要跟后台对应起来
  }


  /**
   * 获取所有数据
   * @param {object} opt - 可选，传递给接口的查询参数
   * @returns {Promise<T>}
   */
  $getAllData(opt?: Object): Promise<any> {
    if (IS_DEV) {
      if (!this.$api) {
        throw new Error(`${this.constructor.name}未定义接口地址`);
      }
      if (!this.$listAllAction) {
        throw new Error(`${this.constructor.name}未定义$listAction`);
      }
    }
    const data = {
      action: this.$listAllAction
    };
    if (opt && typeof opt === 'object') {
      Object.assign(data, opt);
    }
    return Ajax.get(this.$api, data).then(result => {
      const data = result.data || [];
      this.$afterGetList(data);
      this.$dataList = data;
      return data;
    });
  }

  /**
   * 获取分页数据
   * @param pageNum
   * @param opt
   * @returns {Promise<T>}
   */
  $getPageData(pageNum: number, opt?: Object): Promise<any> {
    if (IS_DEV) {
      if (!this.$api) {
        throw new Error(`${this.constructor.name}未定义接口地址`);
      }
      if (!this.$listAction) {
        throw new Error(`${this.constructor.name}未定义$listAction`);
      }
    }
    const data = {
      action: this.$listAction,
      limit: this.$limit,
      offset: this.$limit * (pageNum - 1)
    };
    Object.assign(data, this.$searchPara);
    Object.assign(data, opt || {});
    return Ajax.get(this.$api, data).then(result => {
      this.$totalPage = Math.ceil(result.total / this.$limit);
      this.$total = result.total;
      this.$afterGetList(result.data);
      this.$dataList = result.data;
      return result.data;
    });
  }

  /**
   * 获取分页数据
   * @returns {Promise<T>}
   */
  $getPageDataPro(): Promise<any> {
    return this.$getPageData(this.$nowPage);
  }

  $getPage() {
    return this.$getPageData(this.$nowPage);
  }

  /**
   * 根据id获取单条记录
   * @param {number} id - 标识 可不传递
   * @returns {Promise<T>}
   */
  $getData(id): Promise<any> {
    if (IS_DEV) {
      if (!this.$api) {
        throw new Error(`${this.constructor.name}未定义接口地址`);
      }
      if (!this.$getAction) {
        throw new Error(`${this.constructor.name}未定义$getAction`);
      }
    }
    id = id || this.id;
    if (!id) {
      throw new Error('未传入有效ID');
    }
    return Ajax.get(this.$api, {
      action: this.$getAction,
      [this.$idField]: id
    }).then(result => {
      let data;
      if (Array.isArray(result.data)) {
        data = result.data[0];
      } else {
        data = result.data;
      }
      Object.assign(this, data);
      if (this.$idField !== 'id') {
        this.id = parseInt(data[this.$idField]);
      }
      this.$afterGet();
      return this;
    });
  }

  /**
   * 保存数据
   * @param {number} otherData -提交到后台的其他数据
   * @returns {*|Promise<AxiosResponse<any>>}
   */
  $setData(otherData = {}): Promise<any> {
    if (IS_DEV) {
      if (!this.$api) {
        throw new Error(`${this.constructor.name}未定义接口地址`);
      }
      if (!this.$setAction) {
        throw new Error(`${this.constructor.name}未定义$setAction`);
      }
    }

    return Ajax[this.$setMode](this.$api, Object.assign(assign({
      action: this.$setAction
    }, this, this.$keys), otherData));
  }

  /**
   * 删除数据
   * @returns {*|Promise<AxiosResponse<any>>}
   */
  $delData(id?: number): Promise<any> {
    if (IS_DEV) {
      if (!this.$api) {
        throw new Error(`${this.constructor.name}未定义接口地址`);
      }
      if (!this.$delAction) {
        throw new Error(`${this.constructor.name}未定义$delAction`);
      }
    }
    return Ajax[this.$delMode](this.$api, {
      action: this.$delAction,
      [this.$idField]: id || this.id
    });
  }

  /**
   * 删除数据
   * @returns {*|Promise<AxiosResponse<any>>}
   */
  $delDatas(ids: string): Promise<any> {
    return Ajax[this.$delMode](this.$api, {
      action: this.$delAction,
      ids
    });
  }

  /**
   *
   * @param limit
   * @param paras
   * @returns {Rolling_data}
   */
  $rollingData(limit, paras = {}) {
    return new rollingData({
      api: this.$api,
      limit: limit || this.$limit,
      paras: Object.assign({
        action: this.$listAction
      }, paras)
    })
  }
}

export default DataModel;
