/* @flow */

/**
 * 计算时间差，并转化为中文显示
 * @param {Date} end
 * @param {Date} start
 * @param {boolean} showTime
 * @returns {string}
 */
const time_diff = function (start: Date, end: Date, showTime = true) {
  let value = (end.valueOf() - start.valueOf()) / 1000;
  return showTimeDiff(value, showTime);
};

/**
 * 倒计时场景下显示时间
 * @param value - 秒
 * @returns {string}
 */
function showTimeDiff(value, showTime = true) {
  let front = '';
  if (value < 0) {
    value = -value;
    front = '-';
  }
  const d = Math.floor(value / 60 / 60 / 24);
  const h = Math.floor(value / 60 / 60 % 24);
  const m = Math.floor(value / 60 % 60);
  const s = Math.floor(value % 60);
  let result = '';
  if (d > 0) {
    result += d + '天';
  }
  if (h > 0) {
    result += h + '小时';
  }
  if (showTime) {
    if (m > 0) {
      result += m + '分钟';
    }
    if (s > 0) {
      result += s + '秒';
    }
  }
  return front + result;

}

export {time_diff, showTimeDiff};
