import {max_day_of_month} from './max_day_of_month';

/* @flow */


/**
 * 获取时间段
 * @param type
 * @returns {{start: *, end: *}}
 */

const time_slot = function timeSlot(type: string): Object {

    const date = new Date();
    let start, end, lastDay, startDay;

    switch (type) {
        case '上月':
        case 'lastMonth':
        case 'lm':
            date.addMonths(-1);
            lastDay = max_day_of_month(date.getFullYear(), date.getMonth() + 1);
            start = date.format('yyyy-MM-01');
            end = date.format(`yyyy-MM-${lastDay}`);
            break;
        case '本月':
        case 'thisMonth':
        case 'tm':
            lastDay = max_day_of_month(date.getFullYear(), date.getMonth() + 1);
            start = date.format('yyyy-MM-01');
            end = date.format(`yyyy-MM-${lastDay}`);
            break;
        case '本周':
        case 'thisWeek':
        case 'tw':
            startDay = date.addDays(1 - date.getDay());
            start = startDay.dateStr();
            end = date.addDays(6).dateStr();
            break;
        case '上周':
        case 'lastWeek':
        case 'lw':
            startDay = date.addDays(1 - date.getDay() - 7);
            start = startDay.dateStr();
            end = date.addDays(6).dateStr();
            break;
        case '今年':
        case 'thisYear':
        case 'ty':
            start = date.format('yyyy-01-01');
            end = date.format('yyyy-12-31');
            break;

    }
    return {
        start,
        end
    }
};

export {time_slot};
