/**
 * 获取一周属于一年当中的第多少周
 * @param now
 * @returns {number}
 */
const getWeekNo = function (now: Date = new Date()) {
  const startDate = new Date(now.getFullYear(), 0, 1);
  const a = startDate.getDay();
  if (a !== 1) {
    startDate.addDays(-(a - 1));
  }
  return Math.floor(Math.round((now.valueOf() - startDate.valueOf()) / 864e5) / 7) + 1;
};

/**
 * 获取一年当中的第多少周的起始日期
 * @param {number} year
 * @param {number} weekNo - 周编号
 * @returns {Date}
 */
const weekNoToDate = function (year: number, weekNo: number) {
  weekNo = parseInt(weekNo);// 忽略小数
  let startDay = new Date(year, 0, 1); // 一年的起始日
  const weekDay = startDay.getDay();

  if (weekDay === 0) {
    startDay = new Date(year, 0, 2);
  } else {
    startDay.addDays(-(weekDay - 1));
  }

  return startDay.addWeeks(weekNo - 1);
};

/**
 * 显示指定时间的对应的一周开始和结束日期
 * @param {Date} date
 * @returns {string}
 */
const dateToWeekText = function (date: Date) {
  const weekday = date.getDay();
  if (weekday !== 1) {
    date.addDays(-(weekday - 1));
  }
  let result = date.format('yyyy年MM月dd日');
  result += '——';
  result += date.addDays(6).format('MM月dd日');
  return result;
};

const getWeekText = function (date: Date) {
  return [
    '星期天',
    '星期一',
    '星期二',
    '星期三',
    '星期四',
    '星期五',
    '星期六',
  ][date.getDay()];
};
export {
  getWeekNo,
  weekNoToDate,
  dateToWeekText,
  getWeekText
};
