export default {
  /**
   * 添加时间
   * @param element dom对象
   * @param event 待处理的事件。事件名称，不含on，例：click、mouseover、keydown等
   * @param handleFun 处理函数
   */
  addEvent: function (element, event, handleFun) {
    if (element.addEventListener) {
      element.addEventListener(event, function (target) {
        handleFun(target.detail, target)
      }, false);
    } else if (element.attachEvent) {
      //IE8及更早版本
      element.attachEvent(event, handleFun);
    }

  },
  /**
   * 移除事件
   * @param element dom对象
   * @param event 事件名称
   * @param handleFun 处理函数
   */
  removeEvent: function (element, event, handleFun) {
    if (element.removeEventListener) {
      element.removeEventListener(event, handleFun);
    }
    else if (element.detachEvent) {
      //IE8及更早版本
      element.detachEvent("on" + event, handleFun);
    }
    else {
      element["on" + event] = null;
    }
  },

  fireEvent: function (element, eventName, data) {
    const event = document.createEvent("CustomEvent");
    event.initCustomEvent(eventName, false, true, data);
    element.dispatchEvent(event);//IE9以下不被支持
  },
  //阻止事件冒泡
  stopPropagation: function (event) {
    if (event.stopPropagation) {
      event.stopPropagation();
    } else {
      event.cancelBubble = true;//IE阻止事件冒泡，true代表阻止
    }
  },
  //阻止事件默认行为
  preventDefault: function (event) {
    if (event.preventDefault) {
      event.preventDefault();
    } else {
      event.returnValue = false;//IE阻止事件冒泡，false代表阻止
    }
  },
  /**
   * 获得事件元素
   * @param event
   * @returns {*|Element}
   */
  getElement: function (event) {
    //event.target--非IE
    //event.srcElement--IE
    return event.target || event.srcElement;
  },
  //获得事件
  getEvent: function (event) {
    return event ? event : window.event;
  },
  //获得事件类型
  getType: function (event) {
    return event.type;
  }
};
