export default {
  /**
   * 压缩图片 本方法仅限制最大图片宽度，不限制图片高度
   * @param src - 图片数据
   * @param maxWidth - 最大图片宽度
   * @param prop - 压缩比
   * @returns {Promise<any>}
   */
  img2Blob(src, maxWidth = 1000, prop = 0.6) {
    const img = new Image();
    const canvas = document.createElement('canvas');
    const cxt = canvas.getContext('2d');

    return new Promise(function (resolve) {
      img.onload = function () {
        if (img.width <= maxWidth) {
          canvas.width = img.width;
          canvas.height = img.height;
        }
        else {
          const bili = img.width / maxWidth;
          canvas.width = maxWidth;
          canvas.height = img.height / bili;
        }
        cxt.drawImage(img, 0, 0, canvas.width, canvas.height);
        const data = canvas.toDataURL('image/jpeg');
        const text = window.atob(data.split(',')[1]);
        const buffer = new Uint8Array(text.length);
        for (let i = 0; i < text.length; i++) {
          buffer[i] = text.charCodeAt(i);
        }
        const blob = new Blob([buffer], {
          type: 'image/jpeg'
        });
        console.log(img.width, img.height);
        console.log(canvas.width, canvas.height);
        resolve(blob);
      };
      img.src = src;
    });
  },

  imgHeight(bili, maxWidth = 760, blank = 0) {
    const winWidth = window.innerWidth || 375;
    if (winWidth < maxWidth) {
      maxWidth = winWidth;
    }
    this.height = (maxWidth - blank) / bili;
  }
}
