import MyMath from './basic';
import Global from './global';

/**
 * 加载资源文件
 * @param {array|null} js
 * @param {array|null} css
 * @param {function|null}callback
 */
function loadRes(js, css, callback) {
  if (css) {
    css.forEach(function (src) {
      loadCss(src);
    });
  }
  if (js) {
    const src = js.shift();
    if (src) {
      loadJs(src, function () {
        loadRes(js, false, callback);
      });
    } else {
      if (typeof callback === 'function') {
        callback();
      }
    }
  }
}

/**
 * 加载Css文件
 * @param src
 */
function loadCss(src, id) {
  const head = document.getElementsByTagName('head')[0];
  const link = document.createElement('link');
  link.href = src;
  link.rel = 'stylesheet';
  link.type = 'text/css';
  if (id) {
    link.id = id;
  }
  head.appendChild(link);

}

/**
 * 加载js文件，成功后执行回调
 * @param src - 文件路径
 * @param callback - 回调
 */
function loadJs(src, callback) {
  const head = document.getElementsByTagName('head')[0];
  const script = document.createElement('script');
  script.src = src;
  script.type = 'text/javascript';
  if (typeof callback === 'function') {
    script.onload = callback;
  }
  head.appendChild(script);
}

/**
 * 加载模块
 * @param name - 模块所使用的全局变量名称
 * @param src - js文件(string:加载单个文件，不加载css文件，array：加载多个js和css)
 * @param css -css文件
 * @returns {Promise<any>}
 */
function loadModule(name, src, css) {
  return new Promise(function (resolve, reject) {
    const result = window[name];
    if (result) {
      resolve(result);
    } else {
      switch (MyMath.getType(src)) {
        case 'String':
          loadJs(src, function () {
            resolve(window[name]);
          });
          break;
        case 'Array':
          loadRes(src, css, function () {
            resolve(window[name]);
          });
          break;
      }
    }
  });
}

/**
 * 引入jquery
 * @returns {Promise<any>}
 */
function loadJquery() {
  return loadModule('jQuery', Global.get('jquerySrc'));
}

/**
 * 引入百度Echarts
 * @returns {Promise<any>}
 */
function loadEcharts() {
  return loadModule('echarts', '//cdn.bootcss.com/echarts/4.0.4/echarts.min.js');
}

export {
  loadRes,
  loadCss,
  loadJs,
  loadModule,
  loadJquery,
  loadEcharts
}
