/* @flow weak */
import Ajax from "./ajax";
import {assign} from "./basic";
import baseModel from "./base_model";
import rollingData from "../mobile/rolling_data";

/**
 * 数据实体基类 MVC接口模式
 */
class Model_basic extends baseModel {

  constructor() {
    super();

    this.$apiGetAll = '';           // list接口地址
    this.$apiGetPage = '';           // 分页list接口地址
    this.$apiGet = '';             // get单条数据 接口地址

    this.$apiSet = '';             // 保存（添加、修改）数据 接口地址
    this.$apiAdd = '';             // 添加接口
    this.$apiEdit = '';             // 保存接口

    this.$apiDel = '';           // 删除数据 接口地址
    this.$limit = 20;

  }


  /**
   * 获取所有数据
   * @param {object} opt - 可选，传递给接口的查询参数
   * @returns {Promise<T>}
   */
  $getAllData(opt?: Object): Promise<any> {
    if (IS_DEV) {
      if (!this.$apiGetAll) {
        throw new Error(`${this.constructor.name}未定义$listApi`);
      }
    }
    return Ajax[this.$listMode](this.$apiGetAll, opt).then(data => {
      data = data || [];//自动处理后端空数组返回null的情况
      this.$arrayConvert(data);
      this.$afterGetList(data);
      this.$dataList = data;
      return data;
    });
  }

  /**
   * 获取分页数据
   * @param pageNum - 页码
   * @param opt - 查询参数
   * @returns {Promise<T>}
   */
  $getPageData(pageNum: number, opt?: Object): Promise<any> {
    if (IS_DEV) {
      if (!this.$apiGetPage) {
        throw new Error(`${this.constructor.name}未定义$getPageApi`);
      }
    }
    return Ajax.getPage(
      this.$apiGetPage,
      pageNum,
      {
        limit: this.$limit,
        paras: Object.assign({}, this.$searchPara, opt || {})
      },
      this.$listMode).then(result => {
      this.$total = result.total;
      this.$totalPage = Math.ceil(result.total / this.$limit);
      const data = result.data || [];//自动处理后端返回null的情况
      this.$arrayConvert(data);
      this.$afterGetList(data);
      this.$dataList = data;
      return data;
    });
    /*
    return Ajax.get(this.$apiGetPage, data).then(result => {
      this.$total = result.total;
      this.$totalPage = Math.ceil(result.total / this.$limit);
      this.$dataList = result.data;
      this.$afterGetList(result.data);
      return result.data;
    });
    */
  }


  /**
   * 获取分页数据
   * @returns {Promise<T>}
   */
  $getPageDataPro(): Promise<any> {
    return this.$getPageData(this.$nowPage);
  }

  $getPage() {
    return this.$getPageData(this.$nowPage);
  }

  /**
   * 根据id获取单条记录
   * @param {number} id - 标识 可不传递
   * @param {number} key - 往后台提交的id值
   * @returns {Promise<T>}
   */
  $getData(id, key): Promise<any> {
    if (IS_DEV) {
      if (!this.$apiGet) {
        throw new Error(`${this.constructor.name}未定义$getApi`);
      }
    }
    id = id || this.id;
    if (!id) {
      throw new Error('未传入有效ID');
    }
    return Ajax.get(this.$apiGet, {
      [key || this.$idField]: id
    }).then(data => {
      this.$convertServerData(data);
      Object.assign(this, data);
      if (this.$idField !== 'id') {
        this.id = parseInt(data[this.$idField]);
      }
      this.$afterGet();
      return this;
    });
  }

  /**
   * 保存数据
   * @param {number} otherData -提交到后台的其他数据
   * @returns {*|Promise<AxiosResponse<any>>}
   */
  $setData(otherData = {}): Promise<any> {
    const data = this.$convertLocalData();
    let api = this.id ? (this.$apiSet || this.$apiEdit) : (this.$apiSet || this.$apiAdd);
    if (IS_DEV) {
      if (!api) {
        throw new Error(`${this.constructor.name}未定义数据保存Api`);
      }
    }

    return Ajax[this.$setMode](api, Object.assign(assign(data, this, this.$keys), otherData)).then(data => {
      if (!this.id) {
        //数据添加成功后，自动清除查询条件
        this.$searchPara = {};
      }
      return data;
    });
  }

  /**
   * 删除数据
   * @returns {*|Promise<AxiosResponse<any>>}
   */
  $delData(id, key): Promise<any> {
    if (IS_DEV) {
      if (!this.$apiDel) {
        throw new Error(`${this.constructor.name}未定义$delApi`);
      }
    }
    return Ajax[this.$delMode](this.$apiDel, {
      [key || this.$idField]: id || this.id
    });
  }


  /**
   *
   * @param limit
   * @param paras
   * @returns {Rolling_data}
   */
  $rollingData(limit, paras = {}) {
    return new rollingData({
      api: this.$apiGetPage,
      limit: limit || this.$limit,
      paras: paras
    })
  }

}

export default Model_basic;
