/* @flow weak */
import {getType} from './basic';

const tools = {
  /**
   *把数据集转化为value、label的数据集，用于前端统一变量名
   * @param data
   * @param valueId
   * @param labelId
   * @returns {Array}
   */
  convert(data: Array, valueId: string, labelId: string) {
    const result = [];
    data.forEach(function (item) {
      result.push({
        value: item[valueId],
        label: item[labelId]
      });
    });
    return result;
  },
  getValue(list: Array, label) {
    const item = list.filter(function (item) {
      return item.label === label;
    })[0];
    return item ? item.value : '';
  },
  getLabel(list: Array, value): string {
    const item = list.filter(function (item) {
      return item.value === value;
    })[0];
    return item ? item.label : '';
  },
  getName(list: Array, value): string {
    const item = list.filter(function (item) {
      return item.value === value;
    })[0];
    return item ? item.name : '';
  },

  strToList(source) {
    return source.map(function (item, index) {
      return {
        value: index,
        label: item,
        checked: false
      }
    });
  },
  setChecked(data, value) {
    if (Array.isArray(value)) {
      value.forEach(function (_value) {
        const item = data.find(function (item) {
          return item.value === _value;
        });
        if (item) {
          item.checked = true;
        }
      });
    } else {
      const item = data.find(function (item) {
        return item.value === value;
      });
      if (item) {
        item.checked = true;
      }
    }
  }
};

export default tools;

class Options {

  constructor(data: Array, valueKey = 'value', labelKey = 'label') {
    this.data = [];
    this.valueKey = valueKey;
    this.labelKey = labelKey;
    if (data.length === 0) {
      return;
    }

    this.init(data);
  }

  /**
   * 初始化数据
   * @param data
   */
  init(data) {
    switch (getType(data[0])) {
      case 'String':
        this.data = data.map(function (item, index) {
          return {
            value: index,
            label: item,
            checked: false
          }
        });
        break;
      case 'Object':
        this.data = tools.convert(data, this.valueKey, this.labelKey);
        break;
    }

  }

  /**
   * 通过Value取label
   * @param label
   * @returns {*}
   */
  getValue(label) {
    return tools.getValue(this.data, label);
  }

  /**
   * 通过Label取value
   * @param value
   * @returns {*|string}
   */
  getLabel(value) {
    return tools.getLabel(this.data, value);
  }
}

export {
  tools,
  Options
}
