import Ajax from './ajax';

const data = {
  accessid: "",
  policy: "",
  signature: "",
  dir: "",
  host: "",
  expire: 1522717312,
  callbackBodyType: '',
  callback: ''

};

function getSignature(serverUrl, postData) {
  return Ajax.postJson(serverUrl, postData).then(result => {
    data.callback = '';
    Object.assign(data, result);
    data.expire = parseInt(data.expire);
  });
}

export default function (serverUrl, blob, dir, useCache, index = '', postData = {}, isPng = false) {
  const formData = new FormData();
  let fileName = dir ? dir : '';
  fileName += new Date().valueOf() + index.toString() + (isPng ? '.png' : '.jpeg');
  formData.append('key', fileName);
  return new Promise(function (resolve, reject) {
    if (useCache) {
      const now = Date.parse(new Date()) / 1000;
      if (data.expire + 3 > now) {
        getSignature(serverUrl, postData).then(() => {
          resolve();
        }).catch(function () {
          reject('OSS签名获取失败');
        });
      } else {
        resolve();
      }
    } else {
      getSignature(serverUrl, postData).then(() => {
        resolve();
      }).catch(function () {
        reject('OSS签名获取失败');
      });
    }
  }).then(() => {
    formData.append('policy', data.policy);
    formData.append('OSSAccessKeyId', data.accessid);
    formData.append('signature', data.signature);
    formData.append('success_action_status', '200');
    formData.append('file', blob, fileName);
    formData.append('callback', data.callback);
    formData.append('callbackBodyType', data.callbackBodyType);
    return {
      host: data.host,
      formData: formData,
      fileName: fileName,
    };
  });
}

/*
DEMO
uploadByOss(blob) {
  const xhr = new XMLHttpRequest();
  let fileName;
  xhr.onreadystatechange = () => {
    if (xhr.readyState === 4 && xhr.status === 200) {
      this.onUploadSuccess({
        imgUrl: 'http://sjfx-uploadfiles.oss-cn-beijing.aliyuncs.com/' + fileName,
        imgId: 0
      });
    }
  };
  xhr.upload.addEventListener('progress', (e) => {
    this.percentage = ~~(100 * e.loaded / e.total) / 2;
  }, false);

  ossUpload(tokenUrl, blob, 'gift', false).then((res) => {
    fileName = res.fileName;
    xhr.open('post', res.host);
    xhr.send(res.formData);
  });
}
 */
