/* @flow weak */
import Ajax from "./ajax";


export default class Page_store {

  constructor(api, action) {
    this.list = [];             // 接口返回的数组
    this.api = api;                  // 接口地址
    this.action = action;                  // 接口地址
    this.total = 0;
    this.totalPage = 0;
    this.limit = 20;

    this.isEmpty = false;
    this.nowPage = 1;
    this.allSelect = new Set();    //所有已选

    this._allSelect = new Set();    //所有已选
    this.lastSelected = [];   //上一次选中
    this.useKeep = false;
  }


  /**
   * 获取分页数据
   * @param pageNum
   * @param opt
   * @returns {Promise<T>}
   */
  load(pageNum: number, opt?: Object): Promise<any> {
    if (IS_DEV) {
      if (!this.api) {
        throw new Error(`${this.constructor.name}未定义接口地址`);
      }
    }
    this.nowPage = pageNum;
    if (this.useKeep) {
      this._allSelect = new Set(Array.from(this.allSelect));
    }
    const data = Object.assign({
      action: this.action,
      limit: this.limit
    }, opt || {});
    return Ajax.getPage(this.api, pageNum, {
      paras: data
    }).then(result => {
      this.total = result.total;
      this.totalPage = Math.ceil(result.total / this.limit);
      this.list = result.data;
      this.isEmpty = this.total === 0;
      return result.data;
    });
    /*
    return Ajax.get(this.api, data).then(result => {
      this.total = result.total;
      this.totalPage = Math.ceil(result.total / this.limit);
      this.list = result.data;
      this.isEmpty = this.total === 0;
      return result.data;
    });
    */
  }

  /**
   * 清空数据
   */
  clear() {
    this.list = [];
    this.totalPage = 0;
    this.total = 0;
  }


  getSelected() {
    return Array.from(this.allSelect);
  }

  /**
   * 保持选中状态
   */
  keepSelect(nowSelected, key: string = 'id') {
    this.useKeep = true;
    const newSelectd = nowSelected.selectProp(key);
    newSelectd.forEach((id) => {
      if (this.lastSelected.indexOf(id) === -1) {
        this.allSelect.add(id);
      }
    });
    const allIds = this.list.selectProp(key);
    allIds.forEach((id) => {
      if (newSelectd.indexOf(id) === -1) {
        this.allSelect.delete(id);
      }
    });
    console.log(Array.from(this.allSelect));
  }

  /**
   * 清除所有选中
   */
  clearSelected() {
    this.allSelect.clear();
    this._allSelect.clear();
  }

  /**
   * 判断是否选中
   * @param item
   * @param key
   * @returns {boolean}
   */
  isSelect(item, key: string = 'id') {
    return this._allSelect.has(item[key])
  }
}
