import {getType} from '../basic';
import tsToDate from '../date_tool/ts_to_date'

export default function () {
  /**
   * 数组排序之升序排列
   * @param {String|null} key - string，可选。当数据item为对象的时候，指定排序的属性名
   * @returns {Array}
   * @constructor
   */
  Array.prototype.Asc = function (key) {
    if (typeof key === 'string') {
      this.sort(function (b, a) {
        return b[key] - a[key];
      });
    } else {
      this.sort(function (b, a) {
        return b - a;
      });
    }
    return this;
  };
  /**
   * 数组排序之降序排列
   * @param {String|null} key - string，可选。当数据item为对象的时候，指定排序的属性名
   * @returns {Array}
   * @constructor
   */
  Array.prototype.Desc = function (key) {
    if (typeof key === 'string') {
      this.sort(function (b, a) {
        return a[key] - b[key];
      });
    } else {
      this.sort(function (b, a) {
        return a - b;
      });
    }
    return this;
  };

  Array.prototype.Remove = function (item) {
    const index = this.indexOf(item);
    if (index > -1) {
      this.splice(index, 1);
    }
  };


  /**
   * 将对象数组中的某个属性重组为一个新的数组
   * @returns {Array}
   */
  Array.prototype.selectProp = function (name) {
    if (typeof name !== 'string' || name.length === 0) {
      return [];
    }
    const result = [];
    this.forEach(function (item) {
      result.push(item[name]);
    });
    return result; 
  };

  /**
   * 将对象数组中的某个属性重组为一个新的数组
   * @returns {Array}
   */
  Array.prototype.selectUniqueProp = function (name) {
    return Array.from(new Set(this.selectProp(name)));
  };


  /**
   * 自动将数据集中的时间戳或标准时间字符串转为时间
   * @param keys
   * @param fmt
   * @returns {Array}
   */
  Array.prototype.convertTime = function (keys, fmt) {
    if (this.length === 0) {
      return this;
    }

    switch (getType(keys)) {
      case 'String':
        keys = keys.split(',');
        break;
      case 'Array':
        break;
      default:
        keys = [];
        Object.keys(this[0]).forEach(function (name) {
          if (/(date|time)$/i.test(name)) {
            keys.push(name);
          }
        });
        break;

    }
    const useFormat = typeof fmt === 'string';
    this.forEach(function (item) {
      keys.forEach(function (key) {
        if (useFormat) {
          item[key] = tsToDate(item[key]).format(fmt);
        } else {
          item[key] = tsToDate(item[key]);
        }
      })
    });
    return this;
  };

  Array.prototype.sum = function (key) {
    let total = 0;
    if (key) {
      this.forEach(function (item) {
        total += item[key];
      });
    } else {
      this.forEach(function (item) {
        total += item;
      });
    }
    return total;
  }

}
