export default function () {

  /**
   * 将Date型数据以指定的格式输出
   * @param fmt 模板，如：yyyy-MM-dd hh:mm:ss
   * @returns {string}
   * @constructor
   */
  Date.prototype.format = function (fmt = 'yyyy-MM-dd hh:mm:ss') {
    const o = {
      "M+": this.getMonth() + 1,                 //月份
      "d+": this.getDate(),                    //日
      "h+": this.getHours(),                   //小时
      "m+": this.getMinutes(),                 //分
      "s+": this.getSeconds(),                 //秒
      // "q+": Math.floor((this.getMonth() + 3) / 3), //季度
      // "S": this.getMilliseconds()             //毫秒
    };
    if (/(y+)/.test(fmt)) {
      fmt = fmt.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
    }
    for (const k in o) {
      if (new RegExp("(" + k + ")").test(fmt)) {
        fmt = fmt.replace(RegExp.$1, (RegExp.$1.length === 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
      }
    }
    return fmt;
  };
  /**
   * 添加天数
   * @param value {int} 天数
   * @returns {Date}
   */
  Date.prototype.addDays = function (value) {
    if (typeof value !== 'number') {
      throw 'addDays参数必须为number';
    }
    this.setDate(this.getDate() + value);
    return this;
  };
  /**
   * 添加周
   * @param value {int}
   * @returns {Date}
   */
  Date.prototype.addWeeks = function (value) {
    if (typeof value !== 'number') {
      throw 'addWeeks参数必须为number';
    }
    return this.addDays(value * 7);
  };
  /**
   * 添加月
   * @param value {int}
   * @returns {Date}
   */
  Date.prototype.addMonths = function (value) {
    if (typeof value !== 'number') {
      throw 'addMonths参数必须为number';
    }
    const d = this.getDate();
    this.setMonth(this.getMonth() + value);
    if (this.getDate() < d) {
      this.setDate(0);
    }
    return this;
  };
  /**
   * 添加年
   * @param value {int}
   * @returns {Date}
   */
  Date.prototype.addYears = function (value) {
    if (typeof value !== 'number') {
      throw 'addYears参数必须为number';
    }
    const m = this.getDate();
    this.setFullYear(this.getFullYear() + value);
    if (m < this.getMonth()) {
      this.setDate(0);
    }
    return this;
  };
  /**
   * 添加分钟
   * @param value {int}
   * @returns {Date}
   */
  Date.prototype.addMinutes = function (value) {
    if (typeof value !== 'number') {
      throw 'addMinutes参数必须为number';
    }
    this.setMinutes(this.getMinutes() + value);
    return this;
  };
  /**
   * 添加小时
   * @param value {int}
   * @returns {Date}
   */
  Date.prototype.addHours = function (value) {
    if (typeof value !== 'number') {
      throw 'addHours参数必须为number';
    }
    this.setHours(this.getHours() + value);
    return this;
  };
  Date.prototype.dateStr = function (hasTime) {
    if (hasTime) {
      return this.format('yyyy-MM-dd 00:00:00');
    } else {
      return this.format('yyyy-MM-dd');
    }
  };
};

