import {getType} from './basic';

/* @flow weak */
export default class Search_store {
  /**
   * 关键列
   * @param fieldName
   */
  constructor() {
    this.data = [];
    this.result = [];
    this.paras = {
    }
  }


  /**
   * 重新加载数据
   * @param data
   */
  setData(data: array<any>) {
    this.data = data;
    this.query();
  }

  /**
   * 设置查询参数
   * @param {string} key - 参数名称
   * @param {string|number|boolean|function|array} value - 参数值
   * 根据参数值的类型不同，执行不同的过滤行为
   * string：模糊查找
   * number、boolean：精确匹配
   * function：filter
   * array：匹配array中任意一项
   */
  setPara(key: string, value: any) {
    this.paras[key] = value;
    this.query();
  }

  /**
   * 移除指定查询参数
   * @param key
   */
  delPara(key: string) {
    delete this.paras[key];
    this.query();
  }

  /**
   * 移除所有查询参数
   * @param key
   */
  clearPara() {
    this.paras = {};
    this.result = this.data;
  }

  /**
   * 执行搜索
   * 该方法不应由外部调用
   */
  query() {
    const keys = Object.keys(this.paras);
    let result = this.data;
    keys.forEach((key) => {
      const value = this.paras[key];
      switch (getType(value)) {
        case 'String':
          if (value) {
            result = result.filter(function (item) {
              return item[key].indexOf(value) > -1;
            });
          }
          break;
        case 'Function':
          result = result.filter(value);
          break;
        case 'Array':
          result = result.filter(function (item) {
            return value.indexOf(item[key]) > -1;
          });
          break;
        case 'Number':
        case 'Boolean':
          result = result.filter(function (item) {
            return item[key] === value;
          });
          break;
      }
    });
    this.result = result;
  }
}
