import {layer} from './layer';
import Check from './check'

class Validate {
  constructor(data, option) {
    this.data = data;
    this.option = option;
  }

  /**
   * 表单校验
   */
  check(data) {
    this.data = data || this.data;
    const rules = [], that = this;
    for (const key in this.option) {
      const value = this.data[key];
      const thisRule = this.option[key];
      const label = thisRule.label;
      const myrules = thisRule.rule.split(',');
      myrules.forEach(function (rule) {
        rules.push({
          key: key,
          label: label,
          value: value,
          rule: rule,
          fun: thisRule.fun,
          reg: thisRule.reg,
          errMsg: thisRule.errMsg
        });
      });
    }
    const errors = [];
    rules.forEach(item => {
      switch (item.rule) {
        case 'notEmpty':
          if (item.value.length === 0) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `请输入${item.label}`
            });
          }
          break;
        case 'mobile':
          if (!/^1\d{10}$/.test(item.value)) {

            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}格式不正确`
            });
          }
          break;
        case 'int':
          if (!/^[-+]?\d*$/.test(item.value)) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}仅允许输入整数`
            });
          }
          break;
        case 'safe':
          if (!Check.isSafe(item.value)) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}禁止输入特殊符号`
            });
          }
          break;
        case 'noSymbol':
          if (!Check.isNotSymbol(item.value)) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}只允许输入汉字、数字和字母`
            });
          }
          break;
        case 'chinese':
        case 'cn':
          if (!Check.isChinese(item.value)) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}仅允许输入汉字`
            });
          }
          break;
        case 'account':
          if (!/^[a-zA-Z0-9_]+$/.test(item.value)) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}仅允许输入数字和字母和下划线`
            });
          }
          break;
        case 'natural':
          if (!/^[+]?\d*$/.test(item.value)) {
            errors.push({
              key: item.key,
              msg: `${item.label}仅允许输入大于0的整数`
            });
          }
          break;
        case 'custom':
          if (!item.reg.test(item.value)) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}校验失败`
            });
          }
          break;
        case 'function':
          if (!item.fun(item.value)) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}校验失败`
            });
          }
          break;
        default://其他 进行长度校验
          checkLen(item);
      }
    });
    return {
      errors: errors,
      success: errors.length === 0
    };

    /**
     * 长度校验
     */
    function checkLen(item) {
      const minReg = /^min\[(\d+)\]/;
      const maxReg = /^max\[(\d+)\]/;
      const lenReg = /^len\[(\d+)-(\d+)\]/;
      const sameReg = /^same\[([a-zA-Z0-9_]+)\]/;
      let success = true;

      if (minReg.test(item.rule)) {
        (function () {
          const result = item.rule.match(minReg);
          const min = parseInt(result[1]);
          success = item.value.length >= min;
          if (!success) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}不能低于${min}个字符`
            });
          }
        })();
      } else if (maxReg.test(item.rule)) {
        (function () {
          const result = item.rule.match(maxReg);
          const max = parseInt(result[1]);
          success = item.value.length <= max;
          if (!success) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}不能超过${max}个字符`
            });
          }
        })();

      } else if (lenReg.test(item.rule)) {
        (function () {
          const result = item.rule.match(lenReg);
          const min = parseInt(result[1]);
          const max = parseInt(result[2]);
          success = item.value.length >= min && item.value.length <= max;
          if (!success) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}长度不能小于${min}，也不能大于${max}`
            });
          }
        })();
      } else if (sameReg.test(item.rule)) {
        (function () {
          const result = item.rule.match(sameReg);
          success = that.data[result[1]] === item.value;
          if (!success) {
            errors.push({
              key: item.key,
              msg: item.errMsg || `${item.label}输入不一致`
            });
          }
        })();
      } else {
        console.log('未定义的校验规则', item.rule);
      }
    }
  }

  /**
   * 表单校验 返回Promise对象
   * @param data
   * @returns {Promise<any>}
   */
  checkPro(data) {
    const result = this.check(data);
    const that = this;
    return new Promise(function (resolve, reject) {
      if (result.success) {
        resolve(that.data)
      } else {
        layer.error(result.errors[0].msg);
        reject(result.errors);
      }
    })
  }
}

export default Validate;
