import {Ajax} from "../index";

class Rolling_data {

  constructor({
                api,
                limit = 10,
                paras = {},
                mode = 'get'
              }) {
    this.api = api;             // 接口地址
    this.limit = limit;         // 每页加载数据条数
    this.paras = paras;         // 提交给接口的其他参数
    this.mode = mode;
    this.dataList = [];         // 数据
    this.pageNum = 1;           // 待加载的下一页数据
    this.totalPage = 0;         // 总页数
    this.isEmpty = false;       // 是否没有任何数据
    this.isEnd = false;         // 是否没有更多数据了
    this.loading = false;       // 是否正在加载
    this.text = {
      loading: '正在加载...',
      end: '没有更多数据了',
      empty: '暂无数据',
    };
    this.status = '正在加载...';
    this.total = 0;
  }

  /**
   * 加载下一页数据
   */
  load() {
    //阻止并发调用
    if (this.loading || this.isEnd) {
      return Promise.resolve();
    }
    this.loading = true;

    this.status = this.text.loading;
    return Ajax.getPage(this.api, this.pageNum, {
      paras: this.paras,
      limit: this.limit
    }, this.mode).then((res) => {
      this.loading = false;
      this.status = '';
      //用forEach避免引发key错误
      res.data.forEach((item) => {
        this.dataList.push(item);
      });
      this.totalPage = Math.ceil(res.total / this.limit);
      this.isEnd = (this.totalPage <= this.pageNum);
      if (this.isEnd) {
        this.status = this.text.end;
      }
      this.isEmpty = res.total === 0;
      this.total = res.total;
      if (this.isEmpty) {
        this.status = this.text.empty;
      }
      this.pageNum++;
      this.afterGetList(res.data, res);
      return res.data;
    }).catch(() => this.loading = false);
  }

  /**
   * 搜索（重新加载）
   * @param newPara - 新的参数
   */
  search(newPara = {}, autoLoad = true) {
    Object.assign(this.paras, newPara);
    this.clear();
    if (autoLoad) {
      return this.load();
    } else {
      return this;
    }
  }

  /**
   * 加载查询参数 并初始化
   * @param newPara - 新的参数
   */
  setPara(newPara = {}) {
    Object.assign(this.paras, newPara);
    this.clear();
  }

  /**
   * 初始化
   * @returns {Rolling_data}
   */
  clear() {
    this.total = 0;
    this.totalPage = 0;
    this.dataList.length = 0;
    this.pageNum = 1;
    this.isEnd = false;
    this.isEmpty = false;
    this.afterClear();
  }

  afterClear() {

  }

  /**
   * 变更提示文字
   * @param obj
   */
  setText(obj) {
    Object.assign(this.text, obj);
  }

  afterGetList(data, res) {
    return data;
  }
}


export default Rolling_data;
